# -*- coding: utf8 -*-

import re

from django import forms
from django.conf import settings

from ldap_inp import LdapAlias
from portailuser.fields import PortailUserField
from django.utils.safestring import mark_safe


class NouvAliasForm(forms.Form):
    prefixes = forms.CharField(
        label="Préfixes",
        widget=forms.Textarea(),
        help_text="Entrez un préfixe (partie de l’alias avant le « @{ECOLE} »)" " par ligne.",
    )

    def __init__(self, ecole, *args, **kwargs):
        super(NouvAliasForm, self).__init__(*args, **kwargs)

        help_ = self.fields["prefixes"].help_text
        help_ = help_.replace("{ECOLE}", settings.EMAIL_BDE[ecole.id - 1])
        self.fields["prefixes"].help_text = help_
        self.ecole = ecole

    def clean_prefixes(self):
        prefixes_text = self.cleaned_data["prefixes"]
        prefixes = [p.strip() for p in prefixes_text.split("\n") if p.strip()]

        if not prefixes:
            raise forms.ValidationError("Entrez au moins un préfixe.")

        for prefix in prefixes:
            if not re.match(r"^[A-Za-z0-9._-]+$", prefix):
                raise forms.ValidationError(f"Le préfixe « {prefix} » contient des caractères invalides.")

            if LdapAlias.objects.filter(cn=prefix, base=self.ecole.dn):
                raise forms.ValidationError(f"Le préfixe « {prefix} » est déjà utilisé par un alias.")

        self.prefixes = [p.encode() for p in prefixes]

        return prefixes_text


class MailForm(forms.Form):
    mail = forms.EmailField(required=False)
    user = PortailUserField(required=False)

    def is_valid(self):
        valid = super(MailForm, self).is_valid()

        if not valid:
            return valid

        if not (self.cleaned_data["mail"] or self.cleaned_data["user"]):
            self._errors["mail"] = mark_safe(
                '<ul class="errorlist"><li>Veuillez rentrer un mail ou/et un user</li></ul>'
            )
            valid = False
        return valid
